@@ -43,6 +43,8 @@
 #include <kauthobjectdecorator.h>
 #include <KIconLoader>
 
+#include <KActivities/ResourceInstance>
+
 #include "MenuItem.h"
 
 class ModuleView::Private {
@@ -341,6 +343,12 @@ void ModuleView::activeModuleChanged(KPageWidgetItem * current, KPageWidgetItem
     }
     // We need to get the state of the now active module
     stateChanged();
+
+    KCModuleProxy * activeModule = d->mPages.value( d->mPageWidget->currentPage() );
+    if (activeModule) {
+        KActivities::ResourceInstance::notifyAccessed(QUrl("kcm:" + activeModule->moduleInfo().service()->storageId()),
+                "org.kde.systemsettings");
+    }
 }
 
 void ModuleView::stateChanged()
@@ -403,4 +411,13 @@ void ModuleView::updateButtons()
     d->mDefault->setEnabled(buttons & KCModule::Default );
 }
 
+void ModuleView::setFaceType(KPageView::FaceType type)
+{
+    d->mPageWidget->setFaceType(type);
+}
+
+KPageView::FaceType ModuleView::faceType() const
+{
+    return d->mPageWidget->faceType();
+}
 
